@@ -183,6 +183,8 @@ pub enum SyntaxError {
     ImportBindingIsString(JsWord),
     ExportBindingIsString,
 
+    ConstDeclarationsRequireInitialization,
+
     TS1003,
     TS1005,
     TS1009,
@@ -487,6 +489,10 @@ impl SyntaxError {
                 "A string literal cannot be used as an exported binding without `from`.".into()
             }
 
+            SyntaxError::ConstDeclarationsRequireInitialization => {
+                "'const' declarations must be initialized".into()
+            }
+
             SyntaxError::TS1003 => "Expected an identifier".into(),
             SyntaxError::TS1005 => "Expected a semicolon".into(),
             SyntaxError::TS1009 => "Trailing comma is not allowed".into(),
