@@ -302,7 +302,10 @@ impl<'a, I: Tokens> Parser<I> {
                 }
                 match &*arg {
                     Expr::Member(..) => {}
-                    Expr::OptChain(e) if matches!(&*e.expr, Expr::Member(..)) => {}
+                    Expr::OptChain(OptChainExpr {
+                        base: OptChainBase::Member(..),
+                        ..
+                    }) => {}
                     _ => self.emit_err(unwrap_paren(&arg).span(), SyntaxError::TS2703),
                 }
             }
